get_extent() calculates the display width for each string in a character vector.
get_max_extent() calculates the maximum display width of all strings in a character vector,
zero for empty vectors.
get_extent() calculates the display width for each string in a character vector.
get_max_extent() calculates the maximum display width of all strings in a character vector,
zero for empty vectors.